require "class"

NetworkPlayer = class()

function NetworkPlayer:__init(x, y)

	self.type = "networkPlayer"
	
	self.x = x
	self.y = y
	
	self.nextX = x
	self.nextY = y
	
	self.direction = "down"
	self.moving = false
	
	self.speed = 30

	self.sprites = {
		up = love.graphics.newImage("resources/sprites/player/up-stand.png"),
		down = love.graphics.newImage("resources/sprites/player/down-stand.png"),
		left = love.graphics.newImage("resources/sprites/player/left-stand.png"),
		right = love.graphics.newImage("resources/sprites/player/right-stand.png")
	}
	
	self.animationSprites = {
		up = love.graphics.newImage("resources/sprites/player/up-walk.png"),
		down = love.graphics.newImage("resources/sprites/player/down-walk.png"),
		left = love.graphics.newImage("resources/sprites/player/left-walk.png"),
		right = love.graphics.newImage("resources/sprites/player/right-walk.png")
	}
	
	for i,sprite in pairs(self.sprites) do
		sprite:setFilter("nearest", "nearest")
	end
	for i,sprite in pairs(self.animationSprites) do
		sprite:setFilter("nearest", "nearest")
	end	
	
	self.animations = {
		up = newAnimation(self.animationSprites.up, 5, 10, .17, 0),
		down = newAnimation(self.animationSprites.down, 5, 10, .17, 0),
		left = newAnimation(self.animationSprites.left, 5, 10, .17, 0),
		right = newAnimation(self.animationSprites.right, 5, 10, .17, 0)
	}
	
	self.width = self.sprites.down:getWidth()
	self.height = self.sprites.down:getHeight()
	
	self.yOffset = self.height - (self.width / 2)
	
	self.physics = physics:addRectangle(self.x + (self.width / 2), self.y + self.height - (self.width / 2), self.width / 2, self.width / 2)

end

function NetworkPlayer:updateState(x, y, direction)
	
	-- magic happens here I guess
	
	self.nextX = x
	self.nextY = y
	self.direction = direction
	
	-- if self.nextY ~= self.y then
		-- if self.nextY < self.y then
			-- self.direction = "up"
		-- else
			-- self.direction = "down"
		-- end
	-- end
	
	-- if self.nextX ~= self.x then
		-- if self.nextX < self.x then
			-- self.direction = "left"
		-- else
			-- self.direction = "right"
		-- end
	-- end
	
	
end

function NetworkPlayer:draw()
	
	if self.direction == "up" then
		if self.moving then
			self.animations.up:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.up, self.x, self.y, 0, 1, 1, 0, 0)
		end
	elseif self.direction == "down" then
		if self.moving then
			self.animations.down:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.down, self.x, self.y, 0, 1, 1, 0, 0)
		end
	elseif self.direction == "left" then
		if self.moving then
			self.animations.left:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.left, self.x, self.y, 0, 1, 1, 0, 0)
		end
	elseif self.direction == "right" then
		if self.moving then
			self.animations.right:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.right, self.x, self.y, 0, 1, 1, 0, 0)
		end
	end
	
end

function NetworkPlayer:update(dt)

	for i, animaiton in pairs(self.animations) do
		animaiton:update(dt)
	end
	
	xDelta = math.abs(self.nextX - self.x)
	yDelta = math.abs(self.nextY - self.y)

	-- magic also happens here
	if xDelta > .1 then
		self.x = self.x + ( (self.nextX - self.x) * 6 * dt)
	else
		self.x = self.nextX
	end
	
	if yDelta > .1 then
		self.y = self.y + ( (self.nextY - self.y) * 6 * dt)
	else
		self.y = self.nextY
	end
	
	if xDelta > .25 or yDelta > .25 then
		self.moving = true
	else
		self.moving = false
	end
	
	self.physics:moveTo(self.x + (self.width / 2), self.y + self.height - (self.width / 2))
	
end