require "class"
require "AnAL"

Player = class()

function Player:__init()

	self.type = "player"
	
	self.x = 16
	self.y = 16
	
	self.direction = "down"
	self.moving = false
	
	self.speed = 30
	
	self.sprite = love.graphics.newImage("player.png")
	self.sprite:setFilter("nearest", "nearest")
	
	self.sprites = {
		up = love.graphics.newImage("resources/sprites/player/up-stand.png"),
		down = love.graphics.newImage("resources/sprites/player/down-stand.png"),
		left = love.graphics.newImage("resources/sprites/player/left-stand.png"),
		right = love.graphics.newImage("resources/sprites/player/right-stand.png")
	}
	
	self.animationSprites = {
		up = love.graphics.newImage("resources/sprites/player/up-walk.png"),
		down = love.graphics.newImage("resources/sprites/player/down-walk.png"),
		left = love.graphics.newImage("resources/sprites/player/left-walk.png"),
		right = love.graphics.newImage("resources/sprites/player/right-walk.png")
	}
	
	for i,sprite in pairs(self.sprites) do
		sprite:setFilter("nearest", "nearest")
	end
	for i,sprite in pairs(self.animationSprites) do
		sprite:setFilter("nearest", "nearest")
	end
	
	self.animations = {
		up = newAnimation(self.animationSprites.up, 5, 10, .17, 0),
		down = newAnimation(self.animationSprites.down, 5, 10, .17, 0),
		left = newAnimation(self.animationSprites.left, 5, 10, .17, 0),
		right = newAnimation(self.animationSprites.right, 5, 10, .17, 0)
	}
	
	self.width = self.sprites.down:getWidth()
	self.height = self.sprites.down:getHeight()
	
	self.yOffset = self.height - (self.width / 2)
	
	self.physics = physics:addRectangle(self.x + (self.width / 2), self.y + self.height - (self.width / 2), self.width / 2, self.width / 2)

end

function Player:draw()

	if self.direction == "up" then
		if self.moving then
			self.animations.up:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.up, self.x, self.y, 0, 1, 1, 0, 0)
		end
	elseif self.direction == "down" then
		if self.moving then
			self.animations.down:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.down, self.x, self.y, 0, 1, 1, 0, 0)
		end
	elseif self.direction == "left" then
		if self.moving then
			self.animations.left:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.left, self.x, self.y, 0, 1, 1, 0, 0)
		end
	elseif self.direction == "right" then
		if self.moving then
			self.animations.right:draw(self.x, self.y)
		else
			love.graphics.draw(self.sprites.right, self.x, self.y, 0, 1, 1, 0, 0)
		end
	end
	
end

function Player:update(dt)

	for i, animaiton in pairs(self.animations) do
		animaiton:update(dt)
	end

	if love.keyboard.isDown("up") then
		self.y = self.y - (self.speed * dt)
		self.direction = "up"
		self.moving = true
	elseif love.keyboard.isDown("down") then
		self.y = self.y + (self.speed * dt)
		self.direction = "down"
		self.moving = true
	end
	
	if love.keyboard.isDown("left") then
		self.x = self.x - (self.speed * dt)
		self.direction = "left"
		self.moving = true
	elseif love.keyboard.isDown("right") then
		self.x = self.x + (self.speed * dt)
		self.direction = "right"
		self.moving = true
	end
	
	self.physics:moveTo(self.x + (self.width / 2), self.y + self.height - (self.width / 2))

end